summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqcheckbox.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqcheckbox.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqcheckbox.cpp b/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
index 37e8eac..0b139bf 100644
--- a/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
+++ b/tqtinterface/qt4/src/widgets/tqcheckbox.cpp
@@ -170,16 +170,16 @@ bool TQCheckBox::isTristate() const
/*!\reimp
*/
-TQSize TQCheckBox::tqsizeHint() const
+TQSize TQCheckBox::sizeHint() const
{
// NB: TQRadioButton::tqsizeHint() is similar
constPolish();
TQPainter p(this);
TQSize sz = tqstyle().tqitemRect(&p, TQRect(0, 0, 1, 1), TQt::ShowPrefix, FALSE,
pixmap(), text()).size();
- return (tqstyle().tqsizeFromContents(TQStyle::CT_CheckBox, this, sz).
+ return (tqstyle().sizeFromContents(TQStyle::CT_CheckBox, this, sz).
expandedTo(TQApplication::globalStrut()));
}
@@ -316,7 +316,7 @@ void TQCheckBox::resizeEvent( TQResizeEvent *e )
TQPainter p(this);
TQSize isz = tqstyle().tqitemRect(&p, TQRect(0, 0, 1, 1), TQt::ShowPrefix, FALSE,
pixmap(), text()).size();
- TQSize wsz = (tqstyle().tqsizeFromContents(TQStyle::CT_CheckBox, this, isz).
+ TQSize wsz = (tqstyle().sizeFromContents(TQStyle::CT_CheckBox, this, isz).
expandedTo(TQApplication::globalStrut()));
update(wsz.width(), isz.width(), 0, wsz.height());
@@ -170,16 +170,16 @@ bool TQCheckBox::isTristate() const
{
- // NB: TQRadioButton::tqsizeHint() is similar
+ // NB: TQRadioButton::sizeHint() is similar
constPolish();
TQPainter p(this);